==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d5/d69/aircraft__cmd_8cpp.js <==
var aircraft__cmd_8cpp =
[
    [ "MovementTerminalMapping", "db/d6a/structMovementTerminalMapping.html", "db/d6a/structMovementTerminalMapping" ],
    [ "AircraftStateHandler", "d5/d69/aircraft__cmd_8cpp.html#af8a56226a6c84b20c6fc4761d69ad7d3", null ],
    [ "AircraftSpeedLimits", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28b", [
      [ "SPEED_LIMIT_TAXI", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28ba875f24ba0bd53d4a46fdf6030b0a4e0f", null ],
      [ "SPEED_LIMIT_APPROACH", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28ba570b9054fa6f2e8c9d283117afd32ed4", null ],
      [ "SPEED_LIMIT_BROKEN", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28ba7a4a7370ee9a192312515c5d6d6d7926", null ],
      [ "SPEED_LIMIT_HOLD", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28ba6ae3f2360898476bff0c6decba3148b4", null ],
      [ "SPEED_LIMIT_NONE", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28baaa7fb8a509c49ed0cae9a7a1105912b2", null ]
    ] ],
    [ "HelicopterRotorStates", "d5/d69/aircraft__cmd_8cpp.html#abcd446238cb6294a8ee3837093edddc0", [
      [ "HRS_ROTOR_STOPPED", "d5/d69/aircraft__cmd_8cpp.html#abcd446238cb6294a8ee3837093edddc0a4db8b060cc4d7a8b7309108111f1c592", null ],
      [ "HRS_ROTOR_MOVING_1", "d5/d69/aircraft__cmd_8cpp.html#abcd446238cb6294a8ee3837093edddc0a4f6d188aa87dd7b487633b8ccff3fafd", null ],
      [ "HRS_ROTOR_MOVING_2", "d5/d69/aircraft__cmd_8cpp.html#abcd446238cb6294a8ee3837093edddc0a17bda7581de9efdea7439ab9aa30aa93", null ],
      [ "HRS_ROTOR_MOVING_3", "d5/d69/aircraft__cmd_8cpp.html#abcd446238cb6294a8ee3837093edddc0ae210d7c405ce6b8ea5b2a8600aee8dbd", null ]
    ] ],
    [ "AircraftController", "d5/d69/aircraft__cmd_8cpp.html#a7f4c3e1084c85b82be6e207676016ba8", null ],
    [ "AircraftEntersTerminal", "d5/d69/aircraft__cmd_8cpp.html#a94808955287af19c75ded0829fbb05c3", null ],
    [ "AircraftEventHandler", "d5/d69/aircraft__cmd_8cpp.html#aa2bc1fd56dbde63ac5c86a74080976fb", null ],
    [ "AircraftEventHandler_AtTerminal", "d5/d69/aircraft__cmd_8cpp.html#a98a9cc6ea9e90f3bd73c8a7db8aaf537", null ],
    [ "AircraftEventHandler_EndLanding", "d5/d69/aircraft__cmd_8cpp.html#a4633dc0c6ec89a34bf4b54677eabe28c", null ],
    [ "AircraftEventHandler_EndTakeOff", "d5/d69/aircraft__cmd_8cpp.html#a01ffc5f29d76fa3da5d5391904db2c2f", null ],
    [ "AircraftEventHandler_EnterHangar", "d5/d69/aircraft__cmd_8cpp.html#ac55904db0a7da5a0d9f808c1e67ec6e2", null ],
    [ "AircraftEventHandler_EnterTerminal", "d5/d69/aircraft__cmd_8cpp.html#aeac6f4c9b26ffa8af6820cc4b5230fe7", null ],
    [ "AircraftEventHandler_Flying", "d5/d69/aircraft__cmd_8cpp.html#ab6ebb06b23f1104744412354eaea64d5", null ],
    [ "AircraftEventHandler_General", "d5/d69/aircraft__cmd_8cpp.html#a1c0c8b87f5026bcc4e164243cec1e402", null ],
    [ "AircraftEventHandler_HeliEndLanding", "d5/d69/aircraft__cmd_8cpp.html#a65c1e0bdf1f0a4a097c4513d99d25085", null ],
    [ "AircraftEventHandler_HeliLanding", "d5/d69/aircraft__cmd_8cpp.html#a1878baab44c49e106a93cf6379925fbb", null ],
    [ "AircraftEventHandler_HeliTakeOff", "d5/d69/aircraft__cmd_8cpp.html#aa8ccb3d3f25e16010ccfbe44836faef5", null ],
    [ "AircraftEventHandler_InHangar", "d5/d69/aircraft__cmd_8cpp.html#a23a24483bbdb8a4bb88522be4526b0d1", null ],
    [ "AircraftEventHandler_Landing", "d5/d69/aircraft__cmd_8cpp.html#a4650015d757382db4fedc0506d1cad60", null ],
    [ "AircraftEventHandler_StartTakeOff", "d5/d69/aircraft__cmd_8cpp.html#ae9151da15eec4f49f5d1556fcba68eb7", null ],
    [ "AircraftEventHandler_TakeOff", "d5/d69/aircraft__cmd_8cpp.html#aa76950dc923d107ca473663a73680d7a", null ],
    [ "AircraftGetEntryPoint", "d5/d69/aircraft__cmd_8cpp.html#a1403709fb89ba99d9b2db866017aa655", null ],
    [ "AircraftHandleDestTooFar", "d5/d69/aircraft__cmd_8cpp.html#a7de3ef79ff4a3b932b60dece6fba9a8d", null ],
    [ "AircraftLandAirplane", "d5/d69/aircraft__cmd_8cpp.html#a667725a4a03b34b17039a4dc7dedcfb9", null ],
    [ "AircraftLeaveHangar", "d5/d69/aircraft__cmd_8cpp.html#a807f0fc837cfef293dc8dd1154014b2e", null ],
    [ "AircraftNextAirportPos_and_Order", "d5/d69/aircraft__cmd_8cpp.html#a3c10cc6a1df8cd405cc954abda4038d3", null ],
    [ "AirportClearBlock", "d5/d69/aircraft__cmd_8cpp.html#a3c574b47d7af53e80e51c115e12636de", null ],
    [ "AirportFindFreeHelipad", "d5/d69/aircraft__cmd_8cpp.html#a856895f521cfdefbfbe30186ab59754f", null ],
    [ "AirportFindFreeTerminal", "d5/d69/aircraft__cmd_8cpp.html#acef2d3c40306de84493567f3fcef5ae0", null ],
    [ "AirportGoToNextPosition", "d5/d69/aircraft__cmd_8cpp.html#ae3e9a612a4ceebffcde95452bf895f01", null ],
    [ "AirportHasBlock", "d5/d69/aircraft__cmd_8cpp.html#a4ffd54f2ca576d1c0fbec00700442bc3", null ],
    [ "AirportMove", "d5/d69/aircraft__cmd_8cpp.html#a7dbdd278585e6ab2975eacf52d2ea0be", null ],
    [ "AirportSetBlocks", "d5/d69/aircraft__cmd_8cpp.html#a56de09aab671ad5939c77c6233652ae7", null ],
    [ "CheckIfAircraftNeedsService", "d5/d69/aircraft__cmd_8cpp.html#aa8fa943495d585eee73f6ee67c4d6af6", null ],
    [ "CmdBuildAircraft", "d5/d69/aircraft__cmd_8cpp.html#a0f0464ef29f477e1436248c596a79ca6", null ],
    [ "CrashAirplane", "d5/d69/aircraft__cmd_8cpp.html#af383a66405ba1eb4083d4fe11155faec", null ],
    [ "DrawAircraftEngine", "d5/d69/aircraft__cmd_8cpp.html#ab830c07ee0874278ba0c4de599e0b9b8", null ],
    [ "FindNearestHangar", "d5/d69/aircraft__cmd_8cpp.html#a2fa44917adb300a5b5b4a4ec984c3924", null ],
    [ "FreeTerminal", "d5/d69/aircraft__cmd_8cpp.html#a2cb22f2a00180a0870ae86362e4ecf82", null ],
    [ "GetAircraftFlightLevel", "d5/d69/aircraft__cmd_8cpp.html#a83f140ade34dadf7a7ad90547d56dea7", null ],
    [ "GetAircraftFlightLevel", "d5/d69/aircraft__cmd_8cpp.html#af14b44bcafa6d6ef8671980d011e59f3", null ],
    [ "GetAircraftFlightLevelBounds", "d5/d69/aircraft__cmd_8cpp.html#aac768c834cdd7d004911180adb32d88a", null ],
    [ "GetAircraftHoldMaxAltitude", "d5/d69/aircraft__cmd_8cpp.html#a71e782e94b03f68d7731d3f704b1c70e", null ],
    [ "GetAircraftIcon", "d5/d69/aircraft__cmd_8cpp.html#a74d440e1baaee9d8bda8f5cd4346d6c0", null ],
    [ "GetAircraftSpriteSize", "d5/d69/aircraft__cmd_8cpp.html#a428aa5cbe71197560ee14b7ebd490727", null ],
    [ "GetNumTerminals", "d5/d69/aircraft__cmd_8cpp.html#a341996cf2234e5163ba84173e1558746", null ],
    [ "GetRotorImage", "d5/d69/aircraft__cmd_8cpp.html#a8cca208880d57e49b71890614c86c945", null ],
    [ "GetTargetAirportIfValid", "d5/d69/aircraft__cmd_8cpp.html#a3b20edf115f7b26e4d406b7b9e34c133", null ],
    [ "GetTileHeightBelowAircraft", "d5/d69/aircraft__cmd_8cpp.html#a416c5a3cf9d358a76ccbb7df0934978e", null ],
    [ "HandleAircraftEnterHangar", "d5/d69/aircraft__cmd_8cpp.html#ad9b1393e081267ef83a685a2f446b27a", null ],
    [ "HandleAircraftSmoke", "d5/d69/aircraft__cmd_8cpp.html#a1582f440fd8cb11702868e6d31027129", null ],
    [ "HandleCrashedAircraft", "d5/d69/aircraft__cmd_8cpp.html#ab06269a3f35b488294cec3ef693497f0", null ],
    [ "HandleMissingAircraftOrders", "d5/d69/aircraft__cmd_8cpp.html#afa1d98bdfee8120da5bf1bfd25ed4530", null ],
    [ "HelicopterTickHandler", "d5/d69/aircraft__cmd_8cpp.html#ac6948b49a8ff88b86aee01cd40f1b209", null ],
    [ "IsValidImageIndex< VEH_AIRCRAFT >", "d5/d69/aircraft__cmd_8cpp.html#a12195b5edce14beee05fb13a7884ef8c", null ],
    [ "MaybeCrashAirplane", "d5/d69/aircraft__cmd_8cpp.html#aa9352b67f86831bfafd4988f34bd3b93", null ],
    [ "PlayAircraftSound", "d5/d69/aircraft__cmd_8cpp.html#a5d5fdb13a468a47a99c08b3932ccfc1f", null ],
    [ "SetAircraftPosition", "d5/d69/aircraft__cmd_8cpp.html#a98ec4b242a19d2e901c72364ea6eea3e", null ],
    [ "UpdateAircraftCache", "d5/d69/aircraft__cmd_8cpp.html#abc64a994e7da6ca60720a52220d4ddc6", null ],
    [ "UpdateAircraftSpeed", "d5/d69/aircraft__cmd_8cpp.html#aa298f1aa1e4eb6090cc0476550dc5738", null ],
    [ "UpdateAirplanesOnNewStation", "d5/d69/aircraft__cmd_8cpp.html#a3b3048da8e6e7158f8c1c9a23fa741b3", null ],
    [ "_aircraft_sprite", "d5/d69/aircraft__cmd_8cpp.html#a51bec169217a09a50603f04b4296ba01", null ],
    [ "_aircraft_state_handlers", "d5/d69/aircraft__cmd_8cpp.html#abe464e8e5d2e2ecf52ce7abfe597aba0", null ],
    [ "_airport_terminal_mapping", "d5/d69/aircraft__cmd_8cpp.html#a4c3cd3c37611301d3431c64ae0b5384a", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d5/d69/aircraft__cmd_8cpp.js <==
var aircraft__cmd_8cpp =
[
    [ "MovementTerminalMapping", "db/d6a/structMovementTerminalMapping.html", "db/d6a/structMovementTerminalMapping" ],
    [ "AircraftStateHandler", "d5/d69/aircraft__cmd_8cpp.html#af8a56226a6c84b20c6fc4761d69ad7d3", null ],
    [ "AircraftSpeedLimits", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28b", [
      [ "SPEED_LIMIT_TAXI", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28ba875f24ba0bd53d4a46fdf6030b0a4e0f", null ],
      [ "SPEED_LIMIT_APPROACH", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28ba570b9054fa6f2e8c9d283117afd32ed4", null ],
      [ "SPEED_LIMIT_BROKEN", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28ba7a4a7370ee9a192312515c5d6d6d7926", null ],
      [ "SPEED_LIMIT_HOLD", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28ba6ae3f2360898476bff0c6decba3148b4", null ],
      [ "SPEED_LIMIT_NONE", "d5/d69/aircraft__cmd_8cpp.html#a258a3f96b259583250e869a86119f28baaa7fb8a509c49ed0cae9a7a1105912b2", null ]
    ] ],
    [ "HelicopterRotorStates", "d5/d69/aircraft__cmd_8cpp.html#abcd446238cb6294a8ee3837093edddc0", [
      [ "HRS_ROTOR_STOPPED", "d5/d69/aircraft__cmd_8cpp.html#abcd446238cb6294a8ee3837093edddc0a4db8b060cc4d7a8b7309108111f1c592", null ],
      [ "HRS_ROTOR_MOVING_1", "d5/d69/aircraft__cmd_8cpp.html#abcd446238cb6294a8ee3837093edddc0a4f6d188aa87dd7b487633b8ccff3fafd", null ],
      [ "HRS_ROTOR_MOVING_2", "d5/d69/aircraft__cmd_8cpp.html#abcd446238cb6294a8ee3837093edddc0a17bda7581de9efdea7439ab9aa30aa93", null ],
      [ "HRS_ROTOR_MOVING_3", "d5/d69/aircraft__cmd_8cpp.html#abcd446238cb6294a8ee3837093edddc0ae210d7c405ce6b8ea5b2a8600aee8dbd", null ]
    ] ],
    [ "AircraftController", "d5/d69/aircraft__cmd_8cpp.html#a7f4c3e1084c85b82be6e207676016ba8", null ],
    [ "AircraftEntersTerminal", "d5/d69/aircraft__cmd_8cpp.html#a94808955287af19c75ded0829fbb05c3", null ],
    [ "AircraftEventHandler", "d5/d69/aircraft__cmd_8cpp.html#aa2bc1fd56dbde63ac5c86a74080976fb", null ],
    [ "AircraftEventHandler_AtTerminal", "d5/d69/aircraft__cmd_8cpp.html#a98a9cc6ea9e90f3bd73c8a7db8aaf537", null ],
    [ "AircraftEventHandler_EndLanding", "d5/d69/aircraft__cmd_8cpp.html#a4633dc0c6ec89a34bf4b54677eabe28c", null ],
    [ "AircraftEventHandler_EndTakeOff", "d5/d69/aircraft__cmd_8cpp.html#a01ffc5f29d76fa3da5d5391904db2c2f", null ],
    [ "AircraftEventHandler_EnterHangar", "d5/d69/aircraft__cmd_8cpp.html#ac55904db0a7da5a0d9f808c1e67ec6e2", null ],
    [ "AircraftEventHandler_EnterTerminal", "d5/d69/aircraft__cmd_8cpp.html#aeac6f4c9b26ffa8af6820cc4b5230fe7", null ],
    [ "AircraftEventHandler_Flying", "d5/d69/aircraft__cmd_8cpp.html#ab6ebb06b23f1104744412354eaea64d5", null ],
    [ "AircraftEventHandler_General", "d5/d69/aircraft__cmd_8cpp.html#a1c0c8b87f5026bcc4e164243cec1e402", null ],
    [ "AircraftEventHandler_HeliEndLanding", "d5/d69/aircraft__cmd_8cpp.html#a65c1e0bdf1f0a4a097c4513d99d25085", null ],
    [ "AircraftEventHandler_HeliLanding", "d5/d69/aircraft__cmd_8cpp.html#a1878baab44c49e106a93cf6379925fbb", null ],
    [ "AircraftEventHandler_HeliTakeOff", "d5/d69/aircraft__cmd_8cpp.html#aa8ccb3d3f25e16010ccfbe44836faef5", null ],
    [ "AircraftEventHandler_InHangar", "d5/d69/aircraft__cmd_8cpp.html#a23a24483bbdb8a4bb88522be4526b0d1", null ],
    [ "AircraftEventHandler_Landing", "d5/d69/aircraft__cmd_8cpp.html#a4650015d757382db4fedc0506d1cad60", null ],
    [ "AircraftEventHandler_StartTakeOff", "d5/d69/aircraft__cmd_8cpp.html#ae9151da15eec4f49f5d1556fcba68eb7", null ],
    [ "AircraftEventHandler_TakeOff", "d5/d69/aircraft__cmd_8cpp.html#aa76950dc923d107ca473663a73680d7a", null ],
    [ "AircraftGetEntryPoint", "d5/d69/aircraft__cmd_8cpp.html#a1403709fb89ba99d9b2db866017aa655", null ],
    [ "AircraftHandleDestTooFar", "d5/d69/aircraft__cmd_8cpp.html#a7de3ef79ff4a3b932b60dece6fba9a8d", null ],
    [ "AircraftLandAirplane", "d5/d69/aircraft__cmd_8cpp.html#a667725a4a03b34b17039a4dc7dedcfb9", null ],
    [ "AircraftLeaveHangar", "d5/d69/aircraft__cmd_8cpp.html#a807f0fc837cfef293dc8dd1154014b2e", null ],
    [ "AircraftNextAirportPos_and_Order", "d5/d69/aircraft__cmd_8cpp.html#a3c10cc6a1df8cd405cc954abda4038d3", null ],
    [ "AirportClearBlock", "d5/d69/aircraft__cmd_8cpp.html#a3c574b47d7af53e80e51c115e12636de", null ],
    [ "AirportFindFreeHelipad", "d5/d69/aircraft__cmd_8cpp.html#a856895f521cfdefbfbe30186ab59754f", null ],
    [ "AirportFindFreeTerminal", "d5/d69/aircraft__cmd_8cpp.html#acef2d3c40306de84493567f3fcef5ae0", null ],
    [ "AirportGoToNextPosition", "d5/d69/aircraft__cmd_8cpp.html#ae3e9a612a4ceebffcde95452bf895f01", null ],
    [ "AirportHasBlock", "d5/d69/aircraft__cmd_8cpp.html#a4ffd54f2ca576d1c0fbec00700442bc3", null ],
    [ "AirportMove", "d5/d69/aircraft__cmd_8cpp.html#a7dbdd278585e6ab2975eacf52d2ea0be", null ],
    [ "AirportSetBlocks", "d5/d69/aircraft__cmd_8cpp.html#a56de09aab671ad5939c77c6233652ae7", null ],
    [ "CheckIfAircraftNeedsService", "d5/d69/aircraft__cmd_8cpp.html#aa8fa943495d585eee73f6ee67c4d6af6", null ],
    [ "CmdBuildAircraft", "d5/d69/aircraft__cmd_8cpp.html#a0f0464ef29f477e1436248c596a79ca6", null ],
    [ "CrashAirplane", "d5/d69/aircraft__cmd_8cpp.html#af383a66405ba1eb4083d4fe11155faec", null ],
    [ "DrawAircraftEngine", "d5/d69/aircraft__cmd_8cpp.html#ab830c07ee0874278ba0c4de599e0b9b8", null ],
    [ "FindNearestHangar", "d5/d69/aircraft__cmd_8cpp.html#a2fa44917adb300a5b5b4a4ec984c3924", null ],
    [ "FreeTerminal", "d5/d69/aircraft__cmd_8cpp.html#a2cb22f2a00180a0870ae86362e4ecf82", null ],
    [ "GetAircraftFlightLevel", "d5/d69/aircraft__cmd_8cpp.html#a425801b67dfaf37352434edd0749a6da", null ],
    [ "GetAircraftFlightLevel", "d5/d69/aircraft__cmd_8cpp.html#af14b44bcafa6d6ef8671980d011e59f3", null ],
    [ "GetAircraftFlightLevel", "d5/d69/aircraft__cmd_8cpp.html#a83f140ade34dadf7a7ad90547d56dea7", null ],
    [ "GetAircraftFlightLevelBounds", "d5/d69/aircraft__cmd_8cpp.html#aac768c834cdd7d004911180adb32d88a", null ],
    [ "GetAircraftHoldMaxAltitude", "d5/d69/aircraft__cmd_8cpp.html#a71e782e94b03f68d7731d3f704b1c70e", null ],
    [ "GetAircraftIcon", "d5/d69/aircraft__cmd_8cpp.html#a74d440e1baaee9d8bda8f5cd4346d6c0", null ],
    [ "GetAircraftSpriteSize", "d5/d69/aircraft__cmd_8cpp.html#a428aa5cbe71197560ee14b7ebd490727", null ],
    [ "GetNumTerminals", "d5/d69/aircraft__cmd_8cpp.html#a341996cf2234e5163ba84173e1558746", null ],
    [ "GetRotorImage", "d5/d69/aircraft__cmd_8cpp.html#a8cca208880d57e49b71890614c86c945", null ],
    [ "GetTargetAirportIfValid", "d5/d69/aircraft__cmd_8cpp.html#a3b20edf115f7b26e4d406b7b9e34c133", null ],
    [ "GetTileHeightBelowAircraft", "d5/d69/aircraft__cmd_8cpp.html#a416c5a3cf9d358a76ccbb7df0934978e", null ],
    [ "HandleAircraftEnterHangar", "d5/d69/aircraft__cmd_8cpp.html#ad9b1393e081267ef83a685a2f446b27a", null ],
    [ "HandleAircraftSmoke", "d5/d69/aircraft__cmd_8cpp.html#a1582f440fd8cb11702868e6d31027129", null ],
    [ "HandleCrashedAircraft", "d5/d69/aircraft__cmd_8cpp.html#ab06269a3f35b488294cec3ef693497f0", null ],
    [ "HandleMissingAircraftOrders", "d5/d69/aircraft__cmd_8cpp.html#afa1d98bdfee8120da5bf1bfd25ed4530", null ],
    [ "HelicopterTickHandler", "d5/d69/aircraft__cmd_8cpp.html#ac6948b49a8ff88b86aee01cd40f1b209", null ],
    [ "IsValidImageIndex< VEH_AIRCRAFT >", "d5/d69/aircraft__cmd_8cpp.html#a12195b5edce14beee05fb13a7884ef8c", null ],
    [ "MaybeCrashAirplane", "d5/d69/aircraft__cmd_8cpp.html#aa9352b67f86831bfafd4988f34bd3b93", null ],
    [ "PlayAircraftSound", "d5/d69/aircraft__cmd_8cpp.html#a5d5fdb13a468a47a99c08b3932ccfc1f", null ],
    [ "SetAircraftPosition", "d5/d69/aircraft__cmd_8cpp.html#a98ec4b242a19d2e901c72364ea6eea3e", null ],
    [ "UpdateAircraftCache", "d5/d69/aircraft__cmd_8cpp.html#abc64a994e7da6ca60720a52220d4ddc6", null ],
    [ "UpdateAircraftSpeed", "d5/d69/aircraft__cmd_8cpp.html#aa298f1aa1e4eb6090cc0476550dc5738", null ],
    [ "UpdateAirplanesOnNewStation", "d5/d69/aircraft__cmd_8cpp.html#a3b3048da8e6e7158f8c1c9a23fa741b3", null ],
    [ "_aircraft_sprite", "d5/d69/aircraft__cmd_8cpp.html#a51bec169217a09a50603f04b4296ba01", null ],
    [ "_aircraft_state_handlers", "d5/d69/aircraft__cmd_8cpp.html#abe464e8e5d2e2ecf52ce7abfe597aba0", null ],
    [ "_airport_terminal_mapping", "d5/d69/aircraft__cmd_8cpp.html#a4c3cd3c37611301d3431c64ae0b5384a", null ]
];
